@@ -4,14 +4,13 @@ use Data::Dumper ();
 use overload     ();
 use constant UNDEF => $ENV{MOJO_LOGF_UNDEF} || '__UNDEF__';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 sub logf {
   my ($self, $c, $level, $format, @args) = @_;
   my $log = $c->app->log;
-
   $log->$level(@args ? sprintf $format, $self->flatten(@args) : $format)
-    if $log->${\"is_$level"};
+    if $log->is_level($level);
   $c;
 }
 
@@ -58,7 +57,7 @@ Mojolicious::Plugin::Logf - Plugin for logging datastructures using sprintf
 
 =head1 VERSION
 
-0.08
+0.09
 
 =head1 DESCRIPTION
 
@@ -89,7 +88,7 @@ code below to get the same functionality as the L</logf> helper:
   helper logf => sub {
     my ($c, $level, $format) = (shift, shift, shift);
     my $log = $c->app->log;
-    return $c unless $log->${ \ "is_$level" };
+    return $c unless $log->is_level($level);
     my @args = map { ref $_ eq 'CODE' ? $_->() : $_ } @_;
     local $Data::Dumper::Indent   = 0;
     local $Data::Dumper::Maxdepth = $Data::Dumper::Maxdepth || 2;
